@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 'v0.1.10'; # VERSION
+our $VERSION = 'v0.2.0'; # VERSION
 
 use Moose;
 use namespace::autoclean;
@@ -14,19 +14,51 @@ with qw(
 
 use Business::CyberSource::Response;
 
+use XML::Compile::SOAP::WSS 0.12;
+
+use XML::Compile::WSDL11;
+use XML::Compile::SOAP11;
+use XML::Compile::Transport::SOAPHTTP;
+
 sub submit {
 	my $self = shift;
 
-	my $ret = $self->_build_soap_request;
+    my $wss = XML::Compile::SOAP::WSS->new( version => '1.1' );
 
-	my $decision    = $ret->valueof('decision'  );
-	my $request_id  = $ret->valueof('requestID' );
-	my $reason_code = $ret->valueof('reasonCode');
+    my $wsdl = XML::Compile::WSDL11->new( $self->cybs_wsdl->stringify );
+    $wsdl->importDefinitions( $self->cybs_xsd->stringify );
 
-	croak 'no decision from CyberSource' unless $decision;
+    my $call = $wsdl->compileClient('runTransaction');
+
+    my $security = $wss->wsseBasicAuth( $self->username, $self->password );
+
+	my ( $answer, $trace ) = $call->(
+		wsse_Security         => $security,
+		merchantID            => $self->username,
+		merchantReferenceCode => $self->reference_code,
+		clientEnvironment     => $self->client_env,
+		clientLibrary         => $self->client_name,
+		clientLibraryVersion  => $self->client_version,
+		purchaseTotals => {
+			currency         => $self->currency,
+			grandTotalAmount => $self->total,
+		},
+		ccCaptureService => {
+			run => 'true',
+			authRequestID => $self->request_id,
+		},
+	);
+
+	$self->trace( $trace );
+
+	if ( $answer->{Fault} ) {
+		croak 'SOAP Fault: ' . $answer->{Fault}->{faultstring};
+	}
+
+	my $r = $answer->{result};
 
 	my $res;
-	if ( $decision eq 'ACCEPT' ) {
+	if ( $r->{decision} eq 'ACCEPT' ) {
 		$res
 			= Business::CyberSource::Response
 			->with_traits(qw{
@@ -34,34 +66,37 @@ sub submit {
 				Business::CyberSource::Response::Role::Capture
 			})
 			->new({
-				request_id     => $request_id,
-				decision       => $decision,
-				reason_code    => $reason_code,
-				currency       => $ret->valueof('purchaseTotals/currency'),
-				datetime       => $ret->valueof('ccCaptureReply/requestDateTime'),
-				amount         => $ret->valueof('ccCaptureReply/amount'  ),
-				reference_code => $ret->valueof('merchantReferenceCode'  ),
-				reconciliation_id   => $ret->valueof('ccCaptureReply/reconciliationID'),
-				capture_reason_code => $ret->valueof('ccCaptureReply/reasonCode'),
+				request_id     => $r->{requestID},
+				decision       => $r->{decision},
+				# quote reason_code to stringify from BigInt
+				reason_code    => "$r->{reasonCode}",
+				reference_code => $r->{merchantReferenceCode},
+				request_token  => $r->{requestToken},
+				currency       => $r->{purchaseTotals}->{currency},
+				datetime       => $r->{ccCaptureReply}->{requestDateTime},
+				amount         => $r->{ccCaptureReply}->{amount},
+				reference_code => $r->{merchantReferenceCode},
+				reconciliation_id => $r->{ccCaptureReply}->{reconciliationID},
+				capture_reason_code => "$r->{ccCaptureReply}->{reasonCode}",
 			})
 			;
 	}
-	elsif ( $decision eq 'REJECT' ) {
+	elsif ( $r->{decision} eq 'REJECT' ) {
 		$res
 			= Business::CyberSource::Response
 			->with_traits(qw{
 				Business::CyberSource::Response::Role::Reject
 			})
 			->new({
-				decision      => $decision,
-				request_id    => $request_id,
-				reason_code   => $reason_code,
-				request_token => $ret->valueof('requestToken'),
+				decision      => $r->{decision},
+				request_id    => $r->{requestID},
+				reason_code   => "$r->{reasonCode}",
+				request_token => $r->{requestToken},
 			})
 			;
 	}
 	else {
-		croak 'decision defined, but not sane: ' . $decision;
+		croak 'decision defined, but not sane: ' . $r->{decision};
 	}
 
 	return $res;
@@ -73,27 +108,6 @@ has request_id => (
 	isa      => 'Str',
 );
 
-sub _build_sdbo {
-	my $self = shift;
-
-	my $sb = $self->_build_sdbo_header;
-
-	$sb = $self->_build_purchase_info( $sb );
-
-	my $capture_service = $sb->add_elem(
-		attributes => { run => 'true' },
-		name       => 'ccCaptureService',
-	);
-
-	$sb->add_elem(
-		name   => 'authRequestID',
-		value  => $self->request_id,
-		parent => $capture_service,
-	);
-
-	return $sb;
-}
-
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -109,7 +123,7 @@ Business::CyberSource::Request::Capture - CyberSource Capture Request Object
 
 =head1 VERSION
 
-version v0.1.10
+version v0.2.0
 
 =head1 SYNOPSIS
 
@@ -148,6 +162,12 @@ Reader: client_env
 
 Type: Str
 
+=head2 cybs_wsdl
+
+Reader: cybs_wsdl
+
+Type: MooseX::Types::Path::Class::File
+
 =head2 currency
 
 Reader: currency
@@ -156,11 +176,19 @@ Type: MooseX::Types::Locale::Currency::CurrencyCode
 
 This attribute is required.
 
+=head2 trace
+
+Reader: trace
+
+Writer: trace
+
+Type: XML::Compile::SOAP::Trace
+
 =head2 password
 
 Reader: password
 
-Type: Str
+Type: MooseX::Types::Common::String::NonEmptyStr
 
 This attribute is required.
 
@@ -176,14 +204,6 @@ This attribute is required.
 
 Additional documentation: 0: test server. 1: production server
 
-=head2 server
-
-Reader: server
-
-Type: MooseX::Types::URI::Uri
-
-This attribute is required.
-
 =head2 request_id
 
 Reader: request_id
@@ -192,6 +212,12 @@ Type: Str
 
 This attribute is required.
 
+=head2 cybs_api_version
+
+Reader: cybs_api_version
+
+Type: Str
+
 =head2 total
 
 Reader: total
@@ -208,6 +234,12 @@ This attribute is required.
 
 Additional documentation: Your CyberSource merchant ID. Use the same merchantID for evaluation, testing, and production
 
+=head2 cybs_xsd
+
+Reader: cybs_xsd
+
+Type: MooseX::Types::Path::Class::File
+
 =head2 reference_code
 
 Reader: reference_code
