@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = 'v0.1.10'; # VERSION
+our $VERSION = 'v0.2.0'; # VERSION
 
 use Moose::Role;
 use namespace::autoclean;
@@ -27,36 +27,6 @@ has foreign_currency => (
 	isa => CurrencyCode,
 );
 
-sub _build_purchase_info {
-	my ( $self, $sb ) = @_;
-
-	my $purchase_totals = $sb->add_elem(
-		name => 'purchaseTotals',
-	);
-
-	$sb->add_elem(
-		name   => 'currency',
-		parent => $purchase_totals,
-		value  => $self->currency,
-	);
-
-	$sb->add_elem(
-		name   => 'grandTotalAmount',
-		value  => $self->total,
-		parent => $purchase_totals,
-	);
-
-	if ( $self->foreign_currency ) {
-		$sb->add_elem(
-			name   => 'foreignCurrency',
-			value  => $self->foreign_currency,
-			parent => $purchase_totals,
-		);
-	}
-
-	return $sb;
-}
-
 1;
 
 # ABSTRACT: CyberSource Purchase Information Role
@@ -70,7 +40,7 @@ Business::CyberSource::Request::Role::PurchaseInfo - CyberSource Purchase Inform
 
 =head1 VERSION
 
-version v0.1.10
+version v0.2.0
 
 =head1 BUGS
 
