@@ -2,21 +2,21 @@ package Business::CyberSource::Response;
 use 5.008;
 use strict;
 use warnings;
-use Carp;
-BEGIN {
-	our $VERSION = 'v0.1.10'; # VERSION
-}
+
+our $VERSION = 'v0.2.0'; # VERSION
+
 use Moose;
 use namespace::autoclean;
 
 with qw( MooseX::Traits );
 
+use MooseX::Types::Moose qw( Str Int );
 use MooseX::Types::CyberSource qw( Decision );
 
 has request_id => (
 	required => 1,
 	is       => 'ro',
-	isa      => 'Str',
+	isa      => Str,
 );
 
 has decision => (
@@ -28,14 +28,14 @@ has decision => (
 has reason_code => (
 	required => 1,
 	is       => 'ro',
-	isa      => 'Int',
+	isa      => Int,
 );
 
 has reason_text => (
 	required => 1,
 	lazy     => 1,
 	is       => 'ro',
-	isa      => 'Str',
+	isa      => Str,
 	builder  => '_build_reason_text',
 );
 
@@ -138,7 +138,7 @@ Business::CyberSource::Response - Response Object
 
 =head1 VERSION
 
-version v0.1.10
+version v0.2.0
 
 =head1 ATTRIBUTES
 
